/**
 * CMI : Cluster Method Invocation
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: cmi@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 * --------------------------------------------------------------------------
 * $Id: ServerId.java 2170 2008-10-14 19:54:48Z loris $
 * --------------------------------------------------------------------------
 */

package org.ow2.cmi.reference;

import java.net.MalformedURLException;
import java.net.UnknownHostException;

import net.jcip.annotations.Immutable;

/**
 * Identify a server.
 * @author Loris Bouzonnet
 */
@Immutable
public final class ServerId extends ServerRef {

    /**
     * Id for serializable class.
     */
    private static final long serialVersionUID = -1852801069075122942L;

    /**
     * Domain name.
     */
    private final String domainName;

    /**
     * Server name.
     */
    private final String serverName;


    /**
     * Construct a new identifier for a server.
     * Check if the given protocol is consistent with the provider URL.
     * @param domainName a domainName
     * @param serverName a serverName
     * @param protocol a name of protocol
     * @param providerURL a provider URL
     * @throws MalformedURLException if the URL is malformed
     * @throws UnknownHostException if the given host cannot be resolved
     */
    public ServerId(
            final String domainName, final String serverName, final String protocol, final String providerURL)
    throws MalformedURLException, UnknownHostException {
        super(protocol, providerURL);
        this.domainName = domainName;
        this.serverName = serverName;
    }

    /**
     * @return domain name
     */
    public String getDomainName() {
        return domainName;
    }

    /**
     * @return server name
     */
    public String getServerName() {
        return serverName;
    }

    @Override
    public boolean equals(final Object obj) {
        return super.equals(obj);
    }

    @Override
    public int hashCode() {
        return super.hashCode();
    }

}
